@@ -145,9 +145,6 @@ func TestFieldInit(t *testing.T) {
 		{".1.2.3", "foo", "", ".1.2.3", "foo", ""},
 		{".iso.2.3", "foo", "", ".1.2.3", "foo", ""},
 		{".1.0.0.0.1.1", "", "", ".1.0.0.0.1.1", "server", ""},
-		{"TEST::server", "", "", ".1.0.0.0.1.1", "server", ""},
-		{"TEST::server.0", "", "", ".1.0.0.0.1.1.0", "server.0", ""},
-		{"TEST::server", "foo", "", ".1.0.0.0.1.1", "foo", ""},
 		{"IF-MIB::ifPhysAddress.1", "", "", ".1.3.6.1.2.1.2.2.1.6.1", "ifPhysAddress.1", "hwaddr"},
 		{"IF-MIB::ifPhysAddress.1", "", "none", ".1.3.6.1.2.1.2.2.1.6.1", "ifPhysAddress.1", "none"},
 		{"BRIDGE-MIB::dot1dTpFdbAddress.1", "", "", ".1.3.6.1.2.1.17.4.3.1.1.1", "dot1dTpFdbAddress.1", "hwaddr"},
@@ -290,6 +287,10 @@ func TestSnmpInit_noName_noOid(t *testing.T) {
 }
 
 func TestGetSNMPConnection_v2(t *testing.T) {
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+
 	s := &Snmp{
 		Agents: []string{"1.2.3.4:567", "1.2.3.4", "udp://127.0.0.1"},
 		ClientConfig: snmp.ClientConfig{
@@ -359,6 +360,10 @@ func stubTCPServer(wg *sync.WaitGroup) {
 }
 
 func TestGetSNMPConnection_v3(t *testing.T) {
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+
 	s := &Snmp{
 		Agents: []string{"1.2.3.4"},
 		ClientConfig: snmp.ClientConfig{
@@ -399,6 +404,10 @@ func TestGetSNMPConnection_v3(t *testing.T) {
 }
 
 func TestGetSNMPConnection_v3_blumenthal(t *testing.T) {
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+
 	testCases := []struct {
 		Name      string
 		Algorithm gosnmp.SnmpV3PrivProtocol
@@ -518,6 +527,10 @@ func TestGetSNMPConnection_v3_blumenthal(t *testing.T) {
 }
 
 func TestGetSNMPConnection_caching(t *testing.T) {
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+
 	s := &Snmp{
 		Agents: []string{"1.2.3.4", "1.2.3.5", "1.2.3.5"},
 	}
@@ -995,7 +1008,7 @@ func TestFieldConvert(t *testing.T) {
 func TestSnmpTranslateCache_miss(t *testing.T) {
 	snmpTranslateCaches = nil
 	oid := "IF-MIB::ifPhysAddress.1"
-	mibName, oidNum, oidText, conversion, err := SnmpTranslate(oid)
+	mibName, oidNum, oidText, conversion, _, err := SnmpTranslate(oid)
 	require.Len(t, snmpTranslateCaches, 1)
 	stc := snmpTranslateCaches[oid]
 	require.NotNil(t, stc)
@@ -1016,7 +1029,7 @@ func TestSnmpTranslateCache_hit(t *testing.T) {
 			err:        fmt.Errorf("e"),
 		},
 	}
-	mibName, oidNum, oidText, conversion, err := SnmpTranslate("foo")
+	mibName, oidNum, oidText, conversion, _, err := SnmpTranslate("foo")
 	require.Equal(t, "a", mibName)
 	require.Equal(t, "b", oidNum)
 	require.Equal(t, "c", oidText)
@@ -1304,3 +1317,14 @@ func BenchmarkMibLoading(b *testing.B) {
 		require.NoError(b, err)
 	}
 }
+
+func TestCanNotParse(t *testing.T) {
+	s := &Snmp{
+		Fields: []Field{
+			{Oid: "RFC1213-MIB::"},
+		},
+	}
+
+	err := s.Init()
+	require.Error(t, err)
+}
